/**************************************************************************
 * logging.c
 *
 * Generic logging routines.
 *
 * Modified: 2008.076
 *
 * Chad Trabant, IRIS Data Management Center
 **************************************************************************/

#include <errno.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>
#include <pthread.h>
#include <stdarg.h>

#include <libdali.h>

#include "logging.h"

/* Global logging parameters */
int verbose;

/***************************************************************************
 * lprintf:
 *
 * A generic log message handler, pre-pends a current date/time string
 * to each message.  This routine add a newline to the final output
 * message so it should not be included with the message.
 *
 * Returns the number of characters in the formatted message.
 ***************************************************************************/
int
lprintf (int level, const char *fmt, ...)
{
  int rv = 0;
  char message[200];
  va_list argptr;
  struct tm *tp;
  time_t curtime;
  
  char *day[] = {"Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"};
  char *month[] = {"Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul",
                   "Aug", "Sep", "Oct", "Nov", "Dec"};
  
  if ( level <= verbose ) {
    
    /* Build local time string and generate final output */
    curtime = time(NULL);
    tp = localtime (&curtime);

    va_start (argptr, fmt);
    rv = vsnprintf (message, sizeof(message), fmt, argptr);
    va_end (argptr);
    
    printf ("%3.3s %3.3s %2.2d %2.2d:%2.2d:%2.2d %4.4d - %s\n",
            day[tp->tm_wday], month[tp->tm_mon], tp->tm_mday,
            tp->tm_hour, tp->tm_min, tp->tm_sec, tp->tm_year + 1900,
            message);
    
    fflush (stdout);
  }
  
  return rv;
}  /* End of lprintf() */


/***************************************************************************
 * lprint:
 *
 * A simple gateway to lprintf(), trimming trailing newline characters
 * since lprintf() will add one.
 *
 ***************************************************************************/
void
lprint (char *message)
{
  int length;
  char *ptr;
  
  /* Set ptr to last character in the message string */
  length = strlen (message);
  ptr = (char *)message + (length-1); /* Discarding const qualifier, boo hoo */
  
  /* Trim trailing newline characters */
  while ( *ptr == '\n' && ptr != message )
    {
      *ptr-- = '\0';
    }
  
  /* Send message to lprintf() */
  lprintf (0, message);
}  /* End of lprintf() */
